#####################################################################################
####  S1 File: R script to analyze the stability and the variability of groundfish    
####  species assemblages abundance, environmental and fishing variables on the     
####  Mauritanian Exclusive Economic Zone.                 		          
#####################################################################################
#####################################################################################
####   This document is part of the Supporting Information of the article entitled:    
####   "Spatio-Temporal Dynamic of Exploited Groundfish Assemblages Faced to    
####   Environmental and Fishing Forcings: Insights on Mauritanian Exclusive           
####   Economic Zone"                                                                                              
####   by Sakou Oumar Kid, Claude Mant, Laurent Dubroca, Herv Demarcq,     
####   Bastien Mrigot.                                                     
############################################################################
############################################################################
####   Files needed (data set) for running R script                         		            
####   1- "spec.txt"  for species taxonomy                      		            
####   2- "env.txt"   for environmental and fishing variables   	            
####   3- "bio.txt"   for species abundance                     		            
############################################################################
############################################################################
##### packages to load
require(ade4)
require(reshape)
require(lattice)
require(cluster)
require(colorRamps)
require(maptools)
require(rgl)
require(RColorBrewer)
require(ggplot2)
require(cowplot)
require(plotrix)

###### Load data files
#### Load the "spec.txt" data file       
#caracsp<-read.table(file=file.choose(),header=TRUE)
caracsp<-read.table(file="spec.txt",header=TRUE)
caracsp<-caracsp[order(caracsp[,1]),]

#### Load the "env.txt" data file
#env<-read.table(file=file.choose(),header=TRUE)
env<-read.table(file="env.txt",header=TRUE)
names(env)<-c("id","station","y","x","substrate","depth","year","month",
              "season","OpNu","SST","chla")

#### Load the "bio.txt" data file
#bio<-read.table(file=file.choose(),header=TRUE)
bio<-read.table(file="bio.txt",header=TRUE)
names(bio)[1]<-"id"
dat<-merge(env,bio,by.x="id",by.y="id",all.x=T,all.y=T)
tabenv<-dat[,c(10,11,12)]
tabsp<-dat[,13:83]
idyear<-as.factor(dat$year)
idseason<-as.factor(dat$season)
idmonth<-as.factor(dat$month)
idsub<-as.factor((dat$substrate))
defdepth<-c(0,20,50,80,201)
defdepth0<-paste("[",defdepth[1:(length(defdepth)-1)],"-",
          defdepth[2:length(defdepth)],"]",sep="")
defdepth[length(defdepth)]<-defdepth[length(defdepth)]+1
iddepth<-as.factor(defdepth0[findInterval(dat$depth,defdepth)])
### Labels choosen for the four main bathymetric strata
idtab<- factor(iddepth, labels=c("CS","US","MS","OS"))  
table(idtab)

### normed Principal component analysis on Log transformed (x+1) groundfish abundance data table
### and environment & fishing data table
dudi1  <-  dudi.pca(log10(tabsp  +  1),  scale  =  TRUE,  center  =  TRUE,
scan  =  FALSE,  nf  =  6)
dudi2  <-  dudi.pca(tabenv,  scann  =  FALSE,  scale  =  TRUE,  center  =  TRUE,
        nf  =  6)

#### Co-inertia analysis of tables series crossed between 
###  variables calculated in the two tables        
wit1  <-  wca(dudi1,  idtab,  scan  =  FALSE,  nf  =  6)
wit2  <-  wca(dudi2,  idtab,  scan  =  FALSE,  nf  =  6)
kta1  <-  ktab.within(wit1)
kta2  <-  ktab.within(wit2)
kcoi  <-  ktab.match2ktabs(kta1,  kta2)

###  Partial triadic analysis used to analyse the series of crosstabs
ptacoi  <-  pta(kcoi,  scan  =  FALSE,  nf  =  6)

##### The functions used to achieve the graphical STATICO output 
##### used in the manuscrit
pltinter<-function(ptacoi)          {
  axepercent<-round(ptacoi$RV.eig/sum(ptacoi$RV.eig)*100,0)
  texte<-paste("Axis 1:",axepercent[1],"% / Axis 2:",axepercent[2],
  "% of the total inertia")
          s.corcircle(ptacoi$RV.coo[,1:2],fullcircle=FALSE,cgrid=1,
          possub="topleft",sub=texte)
          l0 <- length(ptacoi$RV.eig)
          add.scatter.eig(ptacoi$RV.eig, l0, 1, 2, 
          posi = "bottomleft", ratio = 1/4)
                                    }
pltcompenv<-function(ptacoi)        {
 axepercent<-as.character(round(ptacoi$eig/sum(ptacoi$eig)*100,1))
  pc1<-paste("PC 1 (",axepercent[1],"%)")
  pc2<-paste("PC 2 (",axepercent[2],"%)")
  pc3<-paste("PC 3 (",axepercent[3],"%)")
          plot(ptacoi$co[,1,2],type="n",xlab=pc1,ylab=pc2,
          main="Compromise: axes 1 and 2")
          abline(h=0,v=0)
          s.arrow(ptacoi$co, possub = "topleft",add.=TRUE)
          plot(ptacoi$co[,c(1,3)],type="n",xlab=pc1,ylab=pc3,
          main="Compromise: axes 1 and 3")
          abline(h=0,v=0)
          s.arrow(ptacoi$co[,c(1,3)], possub = "topleft",add.=TRUE)
                                    }
pltcompsp<-function(ptacoi,caracsp) {
  axepercent<-as.character(round(ptacoi$eig/sum(ptacoi$eig)*100,1))
  pc1<-paste("PC 1 (",axepercent[1],"%)")
  pc2<-paste("PC 2 (",axepercent[2],"%)")
  pc3<-paste("PC 3 (",axepercent[3],"%)")
        clusfct <- function(x,k){
        tree1<-as.hclust(agnes(dist(x),method="average"))
        gp1<-cutree(tree1,k)
        return(list(cluster=gp1))
                                    } 
        pipo<-clusGap(ptacoi$li[,1:3],clusfct,10,B=1000,verbose=FALSE)
        maxgp<-maxSE(pipo$Tab[-c(1:3),3],pipo$Tab[-c(1:3),4],"Tibs2001SEmax")+3
        tree1<-as.hclust(agnes(dist(ptacoi$li[,1:3]),method="average"))
        gp1<-cutree(tree1,maxgp)
        plot(pipo)
        abline(h=gp1)
        print(ftable(caracsp[,2],gp1))
        plot(ptacoi$li[,1,2],type="n",xlab=pc1,ylab=pc2,
        main="Compromise: species"); abline(h=0,v=0)
        s.class(ptacoi$li[,1,2],as.factor(gp1),cell=0,cstar=1,cgrid=0,
        axesell=FALSE,add.plot=TRUE,col=rep("dark grey",length(unique(gp1))))
        pointLabel(ptacoi$li[,1],ptacoi$li[,2],labels=nomcourt,cex=.6,doPlot=T)
        plot(ptacoi$li[,c(1,3)],type="n",xlab=pc1,ylab=pc3,
        main="Compromise: species"); abline(h=0,v=0)
        s.class(ptacoi$li[,c(1,3)],as.factor(gp1),cell=0,cstar=1,cgrid=0,
        axesell=FALSE,add.plot=TRUE,col=rep("dark grey",length(unique(gp1))))
        pointLabel(ptacoi$li[,1],ptacoi$li[,3],labels=nomcourt,cex=.6,doPlot=T)
                                                      }
pltstatico<-function(ptacoi,caracsp,idtab,label,dat)  {
        pltinter(ptacoi)
        pltcompenv(ptacoi)
        pltcompsp(ptacoi,caracsp)
                                                      }
############################
# Interstructure Fig 4
############################
pltinter(ptacoi)


###


#### Functions generating temporal trajectories (Years)
plttraj<-function(ptacoi,caracsp,idtab,idyear,whichyear=1997:2010){
        pipo<-ptacoi$supIX
        pipo$id<-"Species assemblages"
        pipo$year<-idyear
        pipo$idtab<-idtab
        pipo2<-ptacoi$supIY
        pipo2$id<-"Environment and fishing effort"
        pipo2$year<-idyear
        pipo2$idtab<-idtab
        pipo<-rbind(pipo,pipo2)
        names(pipo)[1:3]<-c("Axis.1","Axis.2","Axis.3")
        couleur<-c("red","blue")
        trellis.par.set(superpose.symbol = list(col=couleur,pch=20),
        superpose.line=list(col=couleur))
        cloud(Axis.3~Axis.2+Axis.1|year*idtab,data=pipo,relation="free",
        group=id,cex=.5,scales=list(arrows=FALSE,cex=.6,relation="free"),
        type=c("p","h"),auto.key = list(columns=2,cex=1,title="Trajectories"),
        subset=year%in%whichyear)
                                                                  }
 ##### Functions generating spatial trajectories for some statistical squares 
 ##### in the three main geographical areas (North, Center and South)
 plttrajstation<-function(ptacoi,caracsp,idtab,idyear,dat,
            limxy=c(-17.5,-17.4,19.5,20.5))               {
        pipo<-ptacoi$supIX
        pipo$id<-"Species assemblages"
        pipo$year<-idyear
        pipo$idtab<-idtab
        pipo$station<-dat$station
        pipo2<-ptacoi$supIY
        pipo2$id<-"Environment and fishing effort"
        pipo2$year<-idyear
        pipo2$idtab<-idtab
        pipo2$station<-dat$station
        pipo<-rbind(pipo,pipo2)
        names(pipo)[1:3]<-c("Axis.1","Axis.2","Axis.3")
        testx<-limxy[1]<=dat$x&dat$x<=limxy[2]
        testy<-limxy[3]<=dat$y&dat$y<=limxy[4]
        pipo0<-pipo[testx&testy,]
        couleur<-matlab.like(14)
        titre<-paste("Trajectories in",limxy[1],"and",limxy[2],"/",
        limxy[3],"and",limxy[4])
        trellis.par.set(superpose.symbol = list(col=couleur,cex=2,pch=20),
        superpose.line=list(col=couleur))
        cloud(Axis.3~Axis.2+Axis.1|id,data=pipo0,relation="free",cex=2,
        group=year,scales=list(arrows=FALSE,cex=1,relation="free"),
        type=c("p","h"),auto.key = list(columns=4,cex=1,title=titre))
                                                            }
oldcode<-function(ptacoi,caracsp,idtab,label,dat)           {
        if(FALSE)                                           {
        listidtab<-as.character(sort(unique(idtab)))
        listyear<-list(1997:2001,2002:2006,2007:2010)
        for(k in 1:3)                                       {
        rangex<-range(c(ptacoi$supIY[,1],ptacoi$supIX[,1]))
        rangey<-range(c(ptacoi$supIY[,2],ptacoi$supIX[,2]))
        for(i in 1:length(listidtab))                       {
        for(j in listyear[[k]])                             {
        test<-as.character(idtab)%in%listidtab[i]&label==j
        xyzenv<-ptacoi$supIY[test,]
        xyzenv$station<-dat$station[test]
        xyzenv$id<-"Environment and fishing effort"
        xyzsp<-ptacoi$supIX[test,]
        xyzsp$station<-dat$station[test]
        xyzsp$id<-"Species assemblages"
        xyz<-rbind(xyzenv,xyzsp)
        label0<-label[test]
        plot(xyz[,1,2],type="n",main=paste(listidtab[i],j),
        xlim=rangex,ylim=rangey)
        symbols(xyzenv[,1],xyzenv[,2],circle=(xyzenv[,3]-min(xyzenv[,3])),
        inches=.2,add=T,fg="red")
        symbols(xyzsp[,1],xyzsp[,2],circle=(xyzsp[,3]-min(xyzsp[,3])),
        inches=.2,add=T,fg="blue")
        s.class(xyz[,c(1,2)],as.factor(xyz$id),cell=1,cstar=1,cgrid=0,
        axesell=FALSE,add.plot=TRUE,col=c("red","blue"))
                                                              }
                                                              }
                                                              }
                                                              }
                                                              }
  traj2<-function(ptacoi,idtab,label)                         {
  legligne<-c("solid", "dashed", "dotted", "dotdash","longdash")
      rangexbio<-range(ptacoi$supIX[,1])
      rangeybio<-range(ptacoi$supIX[,2])
      rangexenv<-range(ptacoi$supIY[,1])
      rangeyenv<-range(ptacoi$supIY[,2])
      rangex<-range(c(rangexbio,rangexenv))
      rangey<-range(c(rangeybio,rangeyenv))
      print(rangex)
      print(rangey)
      rangex<-c(-2,2)
      rangey<-c(-3,3)
      nbtab<-nrow(ptacoi$RV)
      listtab<-sort(unique(idtab))
      for(i in 1:nbtab)                                       {
      test<-idtab%in%listtab[i]
      xybio<-ptacoi$supIX[test,1:2]
      xyenv<-ptacoi$supIY[test,1:2]
      moisbio<-label[test]
      xbio<-tapply(xybio[,1],moisbio,mean,na.rm=TRUE)
      ybio<-tapply(xybio[,2],moisbio,mean,na.rm=TRUE)
      xenv<-tapply(xyenv[,1],moisbio,mean,na.rm=TRUE)
      yenv<-tapply(xyenv[,2],moisbio,mean,na.rm=TRUE)
      s.class(xybio,as.factor(moisbio),add.plot=FALSE,
      axesell=FALSE,cell=0,clabel=0,xlim=rangex,ylim=rangey,cgrid=1.5,cpoint=0)
      x1bio<-spline(c(xbio,xbio[1]),method="periodic")
      y1bio<-spline(c(ybio,ybio[1]),method="periodic")
      abline(h=0,v=0)
      cpt<-1
      abline(h=0,v=0)
      x1<-spline(c(xenv,xenv[1]),method="periodic")
      y1<-spline(c(yenv,yenv[1]),method="periodic")
      s.class(xyenv,as.factor(moisbio),add.plot=TRUE,
      axesell=FALSE,cell=0,clabel=1.6,cgrid=1.2,cpoint=0)
      lines(x1$y,y1$y,lwd=2.5,col="dark grey")#lty="dotted")
      points(xenv,yenv,pch=20)#lty="dotted")
      for(j in 1:12)                                          {
      lines(c(xbio[j],xenv[j]),c(ybio[j],yenv[j]),lty="dotted")
                                                              }
      lines(x1bio$y,y1bio$y,lwd=3,col="black")#lty="dashed")
      mtext(listtab[i],3,-1,adj=0,cex=1.2)
                                                              }
      plot(0,type="n",frame=FALSE,axes=FALSE)
      legend("bottomleft",c("Species assemblages",
      "Environment and fishing effort"),lty=1,col=c("black","dark grey"),
      lwd=3,bg="white",inset=.06,cex=1.1)
                                                              }
traj1<-function(ptacoi,year,label)                            {
      legligne<-c("solid", "dashed", "dotted", "dotdash","longdash")
      listyear<-sort(unique(year))
      rangexbio<-range(ptacoi$supIX[,1])
      rangeybio<-range(ptacoi$supIX[,2])
      rangexenv<-range(ptacoi$supIY[,1])
      rangeyenv<-range(ptacoi$supIY[,2])
      rangex<-range(c(rangexbio,rangexenv))
      rangey<-range(c(rangeybio,rangeyenv))
      rangey[1]<--3
      print(rangex)
      print(rangey)
      rangex<-c(-2.3,2.1)
      rangey<-c(-3.1,3.4)
      for(i in 1:14)                                            {
      test<-year==1996+i
      xybio<-ptacoi$supIX[test,1:2]
      xyenv<-ptacoi$supIY[test,1:2]
      moisbio<-label[test]
      xbio<-tapply(xybio[,1],moisbio,mean,na.rm=TRUE)
      ybio<-tapply(xybio[,2],moisbio,mean,na.rm=TRUE)
      xenv<-tapply(xyenv[,1],moisbio,mean,na.rm=TRUE)
      yenv<-tapply(xyenv[,2],moisbio,mean,na.rm=TRUE)
      s.class(xybio,as.factor(moisbio),add.plot=FALSE,axesell=FALSE,
      cell=0,clabel=0,xlim=rangex,ylim=rangey,cgrid=1.5,cpoint=0)
      x1bio<-spline(c(xbio,xbio[1]),method="periodic")
      y1bio<-spline(c(ybio,ybio[1]),method="periodic")
      abline(h=0,v=0)
      cpt<-1
      abline(h=0,v=0)
      x1<-spline(c(xenv,xenv[1]),method="periodic")
      y1<-spline(c(yenv,yenv[1]),method="periodic")
      lines(x1$y,y1$y,lwd=2.5,col="dark grey")#lty="dotted")
      points(xenv,yenv,pch=20)#lty="dotted")
      for(j in 1:12)                                            {
      lines(c(xbio[j],xenv[j]),c(ybio[j],yenv[j]),lty="dotted")
                                                                }
      lines(x1bio$y,y1bio$y,lwd=3,col="black")#lty="dashed")
      s.class(xybio,as.factor(moisbio),add.plot=TRUE,axesell=FALSE,
      cell=0,clabel=1.4,cgrid=1.2,cpoint=0)
      mtext(listyear[i],3,-1,adj=0,cex=1.2)
                                                                }
      plot(0,type="n",frame=FALSE,axes=FALSE)
      legend("bottomleft",
      c("Species assemblages","Environment and fishing effort"),
      lty=1,col=c("black","dark grey"),lwd=3,bg="white",inset=.06,cex=1.1)
                                                                }
################################################################################################
####===================== Compromise analysis ================================####
####========================================================================####
####=====1- Eigenvalues Histogram of the Compromise Analysis======================####
####========================================================================####
     eig<-(ptacoi$eig/sum(ptacoi$eig))*100
     barplot(eig,ylim=c(0,80),border="gray")
     box()

####========================================================================####
####=====2- compromise analysis on environment and fishing effort ===================####
####============================ en 3D parameters (Fig. 5) ============================####
####========================================================================####
      pltcompenv3D<-function(ptacoi)                                        {
      axepercent<-as.character(round(ptacoi$eig/sum(ptacoi$eig)*100,0))
      axis1<-paste("Axis 1 (",axepercent[1],"%)")
      axis2<-paste("Axis 2 (",axepercent[2],"%)")
      axis3<-paste("Axis 3 (",axepercent[3],"%)")
      limx<-c(min(c(ptacoi$co[,1]-.1,-.1)),max(c(ptacoi$co[,1]+.1,.1)))
      limy<-c(min(c(ptacoi$co[,2]-.1,-.1)),max(c(ptacoi$co[,2]+.1,.1)))
      limz<-c(min(c(ptacoi$co[,3]-.1,-.1)),max(c(ptacoi$co[,3]+.1,.1)))
      plot3d(ptacoi$co[,1:3],cex.axis=2,xlim=limx,ylim=limy,zlim=limz,
      xlab=axis1,ylab=axis2,zlab=axis3)
      text3d(ptacoi$co[,1:3],cex=2,text=rownames(ptacoi$co))
      for(i in 1:3)                                                   {
      segments3d(rbind(ptacoi$co[i,1:3],c(0,0,0)),lwd=1.5)
                                                                      }
                                                                      }
    pltcompenv3D(ptacoi)
    planes3d(0,0,1,col="gray100",alpha=.5)
    planes3d(1,0,0,col="gray20",alpha=.5)
    planes3d(0,1,0,col="white",alpha=.5)

####========================================================================####  
####=====3- Compromise analysis on groundfish species assemblages ==================####
####========================================================================####
#### A UPGMA method of classification performed at the compromise analysis step 
#### on 71 groundfish species, in order to identify assemblages
      tree<-hclust(dist(ptacoi$li[,c(1,2,3)]),method="average")
      gp<-cutree(tree,k=4)

#### Labels groups representing the main groundfish species assemblages
    labeltemp<-gp
    ftable(row.names(ptacoi$li),gp)
    gp <- factor(gp, labels=c("COA","INZ","EDG","SHE"))
    tapply(row.names(ptacoi$li),gp,print)

#### Factor maps plots of the compromise analysis for 2 axes (Fig. 6)
    plot(ptacoi$li[,c(1,2)],type="n",cex.axis=1,cex.lab=1
     ,xlab="Axis 1 (74%)",ylab="Axis 2 (18%)",xlim=c(-0.6,0.25))
    abline(v=0,h=0,lty=2,col="black")
    s.class(ptacoi$li[,c(1,2)],as.factor(gp),cell = 0, cstar = 1, cgrid = 0, clabel = 0, cpoint = 0, axesell=FALSE,add.plot=TRUE,col=rep("dark grey",nrow(ptacoi$li)))
    gp<-as.character(gp)
    listgp<-unique(gp)
    couleur<-c("red","blue","green","black")
    lcoul<-gp;lcoul[lcoul=="COA"]<-"red"
    lcoul[lcoul=="EDG"]<-"blue"
    lcoul[lcoul=="INZ"]<-"green"
    lcoul[lcoul=="SHE"]<-"black"
    xy0<-data.frame(x=ptacoi$li[,1],y=ptacoi$li[,2])
    xylab<-data.frame(apply(ptacoi$li[,1:2],2,function(a){tapply(a,gp,mean)}))
    xylab0<-xylab
    names(xylab0)<-c("x","y")
    xy1<-rbind(xy0,xylab0)
    xylb<-c(rownames(ptacoi$li),rep("       ",4))
    s.class(ptacoi$li[,c(1,2)],as.factor(gp),cell = 0, cstar = 0, cgrid = 0, clabel = 0, cpoint =1, axesell=FALSE,add.plot=TRUE,col=couleur)
    pointLabel (xy0[,1],xy0[,2], labels = paste("", rownames(ptacoi$li),"", sep=""), cex=.7)
    #mtext("A",side=3,line=-3,cex=3,at=0.2,font=2)
    legend("bottomleft",rownames(xylab),col=couleur,pch=20,pt.cex=2,inset=.01)
    ppi<-300
    dev.copy(png,"fig6.png",w=6*ppi,h=6*ppi,res=ppi)
    dev.off()

#### 3D plot of the assemblage compromise
      pltcompsp3D<-function(ptacoi,gp){
      axepercent<-as.character(round(ptacoi$eig/sum(ptacoi$eig)*100,0))
      axis1<-paste("Axis 1 (",axepercent[1],"%)")
      axis2<-paste("Axis 2 (",axepercent[2],"%)")
      axis3<-paste("Axis 3 (",axepercent[3],"%)")
      limx<-c(min(c(ptacoi$li[,1]-.1,-.0)),max(c(ptacoi$li[,1]+.1,.0)))
      limy<-c(min(c(ptacoi$li[,2]-.1,-.0)),max(c(ptacoi$li[,2]+.1,.0)))
      limz<-c(min(c(ptacoi$li[,3]-.1,-.0)),max(c(ptacoi$li[,3]+.1,.0)))
      plot3d(ptacoi$li[,1:3],cex.axis=2,xlim=limx,ylim=limy,zlim=limz,
      xlab=axis1,ylab=axis2,zlab=axis3,size=0,cex=3)
      gp<-as.character(gp)
      listgp<-unique(gp)
      couleur<-c("red","blue","green","black")
      lcoul<-gp;lcoul[lcoul=="COA"]<-"red"
      lcoul[lcoul=="INZ"]<-"blue"
      lcoul[lcoul=="EDG"]<-"green"
      lcoul[lcoul=="SHE"]<-"black"
      for(j in 1:length(listgp)){
        xyztmp<-ptacoi$li[gp%in%listgp[j],]
	xyz0<-apply(xyztmp,2,mean)
        for(i in 1:nrow(ptacoi$li)){
         segments3d(rbind(xyztmp[i,1:3],xyz0),lwd=2,alpha=.7,color=couleur[j])
        }
	xyz0[3]<--.2
        text3d(xyz0,cex=2,text=listgp[j],color=couleur[j])
       }
      }
    pltcompsp3D(ptacoi,gp)
    planes3d(0,0,1,col="gray100",alpha=.3)
    planes3d(1,0,0,col="gray20",alpha=.3)
    planes3d(0,1,0,col="white",alpha=.3)
    text3d(data.frame(0.3,0,0.3),cex=2,text="B", font=2) 
    rgl.snapshot("fig6.png")


####========================================================================####     
####=================== Trajectories =============================####
####========================================================================####
####   1- define a fonction to plot a stratum for some years with env time series

    #recalculate some stuff (axes 3 in class...)
       pipo<-ptacoi$supIX
       pipo$id<-"Species assemblages"
       pipo$year<-idyear
       pipo$idtab<-idtab
       pipo$idmonth<-idmonth
       pipo$idst<-dat$id
       pipo$idlat<-round(dat$y)
       pipo$x<-dat$x;pipo$y<-dat$y
       pipo2<-ptacoi$supIY
       pipo2$id<-"Environment and fishing effort"
       pipo2$year<-idyear
       pipo2$idtab<-idtab
       pipo2$idmonth<-idmonth
       pipo2$idlat<-round(dat$y)
       pipo2$idst<-dat$id
       pipo2$x<-dat$x;pipo2$y<-dat$y
       pipo<-rbind(pipo,pipo2)
       names(pipo)[1:3]<-c("Axe.1","Axe.2","Axe.3")
       #redefine Axes3 scales
       #seqval<-seq(-5,6,.5)
       seqval<-c(-7,-2,-.1,.1,2,7)
       seqvallab<-paste0("[",seqval[-length(seqval)],",",seqval[-1],"[")
       pipo$a3<-factor(seqvallab[findInterval(pipo$Axe.3,seqval)],levels=seqvallab)
       seqval<-seqval[-1]


####### Trajectories plots for each areas (Fig 7-9)

       #a plot function
     pltcleartrajall<-function(listtab="MS",listyear=c(1997:2010),pipo,dat,namestrat="",limxy){
	if(namestrat==""){
	  titre<-paste0("Trajectory plot for ",unique(pipo$idtab[whichsel]))
	}else{
	  titre<-paste0("Trajectory plot for ",namestrat)
	}
     #spatial selection !
       testx<-limxy[1]<=pipo$x&pipo$x<=limxy[2]
       testy<-limxy[3]<=pipo$y&pipo$y<=limxy[4]
       whichsel<-pipo$idtab%in%listtab&pipo$year%in%listyear&testx&testy
       print(table(whichsel))
       pipo0<-pipo[whichsel,]
       pipo0$year<-as.numeric(as.character(pipo0$year))
       #rescale the value 0->0.5, min->0, max->1
       #pipo0$Axis.1<-rescale(pipo0$Axe.1,c(0,1))
       #pipo0$Axis.2<-rescale(pipo0$Axe.2,c(0,1))
       #pipo0$Axis.3<-rescale(pipo0$Axe.3,c(0,1))
       ###################################################################
	#spline stuff
       xx<-tbl_df(pipo0)%>%group_by(id,idtab,year)%>%summarise(x=mean(Axe.1,na.rm=T),y=mean(Axe.2,na.rm=T),z=mean(Axe.3,na.rm=T))
       print(summary(xx))
       listidtab<-unique(xx$idtab)
       listid<-unique(xx$id)
       xxsp<-data.frame(idtab="",id="",year="",x=NA,y=NA,z=NA)
       par(mfrow=c(4,4))
       for(i in 1:length(listidtab)){
       	for(j in 1:length(listid)){
		xxx<-xx$x[xx$idtab==listidtab[i]&xx$id==listid[j]]
		yyy<-xx$y[xx$idtab==listidtab[i]&xx$id==listid[j]]
		zzz<-xx$z[xx$idtab==listidtab[i]&xx$id==listid[j]]
		yearid<-as.numeric(as.character(xx$year[xx$idtab==listidtab[i]&xx$id==listid[j]]))
		xxxsp<-spline(yearid,xxx,method="fmm",n=100,xout=seq(min(yearid),max(yearid),.1))
		yyysp<-spline(yearid,yyy,method="fmm",n=100,xout=seq(min(yearid),max(yearid),.1))$y
		zzzsp<-spline(yearid,zzz,method="fmm",n=100,xout=seq(min(yearid),max(yearid),.1))$y
		yearid<-xxxsp$x
		xxxsp<-xxxsp$y
		#yyysp<-spline(yyy,method="periodic",n=100)$y
		xxsp<-rbind(xxsp, data.frame(idtab=listidtab[i],id=listid[j],year=yearid,x=xxxsp,y=yyysp,z=zzzsp))
		plot(xxx,yyy)
		lines(xxxsp,yyysp)
	}
       }
       xxsp<-xxsp[-1,];xxsp$xcenter<-xxsp$x;xxsp$ycenter<-xxsp$y;xxsp$year<-as.numeric(xxsp$year)
       #prepare a new pipo with center
       piponew<-left_join(pipo0[,1:6],xx)
       print(summary(xxsp))
       print(summary(pipo0))
       p1<-ggplot(xxsp,aes(x=x,y=y,label=year,colour=z))+
		#geom_segment(data=piponew,aes(x=Axe.1,xend=x,y=Axe.2,yend=y),alpha=1,col="black",linetype="dotted")+
		#geom_point(data=pipo0,aes(x=Axe.1,y=Axe.2,colour=Axe.3),alpha=1)+
       		geom_hline(aes(intercept=0),color="dark grey")+
       		geom_vline(aes(intercept=0),color="dark grey")+
       		geom_path(size=2)+#, arrow = arrow(ends = "last"))+
		#scale_fill_brewer(palette = "Spectral")+
		#scale_colour_gradient2(low="green",mid="blue",high="red",limits=range(xxsp$z))+
		scale_colour_gradient2("Axis 3",limits=range(xxsp$z))+
       		geom_text(data=xx,aes(x=x,y=y,label=substr(year,3,4)),size=4,colour="red")+#,position=position_jitter(h=.2,w=.2))+#, arrow = arrow(ends = "last"))+
       facet_wrap(idtab~id,ncol=2,scale="free")+
       xlab("Axis 1")+ylab("Axis 2")+
       theme(panel.border=element_rect(fill=NA,color="black",size=1,linetype="solid"),
	     strip.background = element_rect(colour="black"),
	     legend.position="bottom",
	     panel.background = element_rect(fill="grey90"),
	      panel.grid.major =  element_line(colour = "white")
	     )+
       background_grid(major = "xy", minor = "none")
       #a quick map
        testx<-limxy[1]<=pipo$x&pipo$x<=limxy[2]
        testy<-limxy[3]<=pipo$y&pipo$y<=limxy[4]
      p0<-ggplot(pipo,aes(x=x,y=y,shape=idtab),asp=.5)+geom_point()+
         geom_point(data=pipo[testx&testy,],aes(x=x,y=y),col="red")+xlab("Longitude")+ylab("Latitude")+
	 coord_fixed()+
       theme(panel.border=element_rect(fill=NA,color="black",size=0.5,linetype="solid"),
	     strip.background = element_rect(colour="black"),
	     legend.position="bottom",
	     panel.background = element_blank())+
       background_grid(major = "xy", minor = "none")
       return(list(p0,p1))
     }

 # pltcleartrajall(c("CS","OS","US","MS"),listyear=c(1997:2010),pipo=pipo,dat=dat,namestrat="the deeper depth stratum",limxy)
 #north
 limsup<-c(17.6,19.2,19.2)
 liminf<-c(16,17.6,17.6)

 
 for(i in 1:3){
  limxy<-c(-20,-15,liminf[i],limsup[i])
  p1<-pltcleartrajall(c("CS","OS","US","MS"),listyear=c(1997:2010),pipo=pipo,dat=dat,namestrat="the deeper depth stratum",limxy)
  plot_grid(p1[[1]], p1[[2]], labels=c("A", "B"), ncol = 2, nrow = 1,rel_widths=c(1,2),label_size=20)

  ggsave(file=paste0("../../figxx_traj_lat",liminf[i],"-",limsup[i],"_no_ind.png"))
  ggsave(file=paste0("../../figxx_traj_lat",liminf[i],"-",limsup[i],"_no_ind.pdf"))
 }



####### THE END  ############################################################

